def find_smallest(arr):
    smallest = arr[0]
    smallest_index = 0

    for i in range(1, len(arr)):
        if arr[i] < smallest:
            smallest = arr[i]
            smallest_index = i
    
    return smallest_index

def selection_sort_to_high(arr):
    new_arr = []

    for i in range(len(arr)):
        smallest = find_smallest(arr)
        new_arr.append(arr.pop(smallest))
    
    return new_arr


from pywork.modules import sort_to_high as sth

def binary_search(list, item):
    low = 0
    high = len(list) - 1
    list = sth.selection_sort_to_high(list)

    while low <= high:
        mid = (low + high)
        guess = list[mid]

        if guess == item:
            return mid
        if guess > item:
            high = mid - 1
        else:
            low = mid + 1 

    return None


def find_biggest(arr):
    biggest = arr[0] 
    biggest_index = 0

    for i in range(1, len(arr)):
        if arr[i] > biggest:
            biggest = arr[i]
            biggest_index = i

    return biggest_index

def selection_sort_to_low(arr):
    new_arr = []

    for i in range(len(arr)):
        biggest = find_biggest(arr)
        new_arr.append(arr.pop(biggest))

    return new_arr